# AccelForge

AccelForge is a framework to design and model tensor algebra accelerators. It includes
models of components, architectures, and workloads, as well as a fast-and-optimal mapper
to program the workloads onto the architectures.

To learn more, see the [AccelForge
documentation](https://accelergy-project.github.io/accelforge/).

## Installation

### Native

AccelForge is available on PyPI:

```bash
pip install accelforge
```

### Docker

TODO

## Notebooks and Examples

Examples can be found in the [`notebooks`](notebooks) directory. Examples of the input
files can be found in the [`examples`](examples) directory.
